/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/*
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/

if(localStorage.getItem('force') === 'false'){
  console.log('force reload');
  localStorage.setItem('force',true)
  //let inter = setInterval( () => {
     location.reload(true)
    // clearInterval(inter);
  //}, 500)
}

var aLangKeys = new Object();
var lang = "";
var back = document.getElementsByClassName('right_col')[0];
let menu_bread = document.getElementById('menu_bread');
var log = localStorage.getItem('log') || false;
var cardsReady = false

var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mon_8","mon_9","mon_10","mon_11"];

var httpSetconfig = new XMLHttpRequest();
var httpreboot = new XMLHttpRequest();

const script_host = location.origin;
const script_ws = script_host.replace('http','ws');

const script_apps= "satteldruckanalyse";
const script_websocket = new WebSocket(`${script_ws}/apps/${script_apps}`, ["soap", "wamp"]);

var script_Data= new Object();
var script_setting = new Object();

var URL_SmartCube = ""

var htdocsInfo = new Object();

script_websocket.onopen = (e)=>{
  console.log('websocket open',e);
  script_websocket.send('get clientsettings')
}

script_websocket.onmessage = (e)=> {
  try {
    script_Data = JSON.parse(e.data);
  } catch (error) {
    getError(error)
  }

  if(script_Data.wsevent ==="clientsettings"){
    script_setting = script_Data.clientsettings
    console.log(script_setting);
    if(script_setting.demo){
      if(document.getElementById('btn_demo_mode'))
      document.getElementById('btn_demo_mode').style.color = document.getElementById('btn_demo_mode') && script_setting.demo == 'true' ? 'var(--warn)' : 'unset';
      document.getElementById('demo_mode').innerHTML = document.getElementById('demo_mode') && script_setting.demo == 'true' ? 'DEMO MODE' : '';
      if(document.getElementById('switch-demo')&& script_setting.demo == 'true'){
        document.getElementById('switch-demo').setAttribute('checked','');
      }
    }
    if(script_setting.bg){
      back.removeAttribute('class')
      back.classList.add('right_col')
      back.classList.add(script_setting.bg)
    }
    if(script_setting.smartcube){
      if(document.getElementById('url_smartcube')){
        document.getElementById('url_smartcube').value = script_setting.smartcube
        localStorage.setItem('smartcube',script_setting.smartcube)
      }
      if(document.getElementById('hip')){
        document.getElementById('hip').value = script_setting.smartcube
        localStorage.setItem('smartcube',script_setting.smartcube)
      }
    }
    try {
      if(script_setting.UserCompany){
        document.getElementById('Company_sidenav').innerHTML = script_setting.UserCompany
        if(document.getElementById('system_user_company')) {
          document.getElementById('system_user_company').value = script_setting.UserCompany
        }
      } else {
        document.getElementById('Company_sidenav').innerHTML = "Velometrik®"
      }
    } catch (error) {
      getError(error)
    }

    try {
      if(script_setting.UserName){
        document.getElementById('User_sidenav').innerHTML = script_setting.UserName
        if(document.getElementById('system_user_name'))
        document.getElementById('system_user_name').value = script_setting.UserName
      }
      if(script_setting.UserCity){
        if(document.getElementById('system_user_city'))
        document.getElementById('system_user_city').value = script_setting.UserCity
      }
      if(script_setting.UserStreet){
        if(document.getElementById('system_user_street'))
        document.getElementById('system_user_street').value = script_setting.UserStreet
      }
      if(script_setting.UserPhone){
        if(document.getElementById('system_user_phone'))
        document.getElementById('system_user_phone').value = script_setting.UserPhone
      }
      if(script_setting.UserWeb){
        if(document.getElementById('system_user_web'))
        document.getElementById('system_user_web').value = script_setting.UserWeb
      }
      if(script_setting.UserMail){
        if(document.getElementById('system_user_mail'))
        document.getElementById('system_user_mail').value = script_setting.UserMail
      }
      if(script_setting.LoginMail){
        if(document.getElementById('system_login_mail'))
        document.getElementById('system_login_mail').value = script_setting.LoginMail
      }
      if(script_setting.LoginPass){
        if(document.getElementById('system_login_pass'))
        document.getElementById('system_login_pass').value = script_setting.LoginPass
      }
      if(script_setting.UserEinleitung && script_setting.UserEinleitung !== ""){
        if(document.getElementById('system_user_einleitung'))
        document.getElementById('system_user_einleitung').value = script_setting.UserEinleitung
      }
    } catch (error) {
      getError(error)
    }

  }

}
script_websocket.onerror= (e)=>{
  if(location.pathname === '/production/dashboard.tcls'){
    return;
  }
  getError(e)
  console.error(e);
}



var devLangKeys = localStorage.getItem('devLang') ? JSON.parse(localStorage.getItem('devLang')) : new Object();


/**
 * It takes a JSON object as a parameter, then loops through all the elements with the attribute "key"
 * and replaces the innerHTML with the value of the key attribute in the JSON object
 * @param params - The object that contains the language keys and their values.
 */
 function _Translate(params) {
  console.log('init translatejs');
  aLangKeys = params
      if(localStorage.getItem('lang')){
          lang = localStorage.getItem('lang')
        }
  if(document.getElementById('lang_list')){
  let lang_list = document.getElementById('lang_list');
  lang_list.innerHTML="";
  
  let zusatzlang = params.zusatzlang;
  let primarylang = params.lang;
  //let li_pl = document.createElement('div');
  let lang_card = newElement({element:'div',cls:['uk-card','uk-card-default','cur_pointer','lang-card'],attr:[['onclick',`langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8')`]]},lang_list)
  let lang_head = newElement({element:'div',cls:['uk-card-header','flex-column-center']},lang_card)
  let lang_img  = newElement({element:'img',cls:['sprachwahl'],attr:[['src',`images/${primarylang.split(' ')[0]}.png`]]},lang_head)
  let lang_body = newElement({element:'div',cls:['uk-card-body','uk-padding-small','uk-text-center']},lang_card).innerHTML = `${primarylang.split(' ')[1]}`
  //let div_pl = document.createElement('div');
  //div_pl.classList.add('col-md-3', 'col-sm-12', 'form-group')
  //div_pl.innerHTML = `<a href="#" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${primarylang.split(' ')[0]}.png"> ${primarylang.split(' ')[1]}</a>`
  //li_pl.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
  //li_pl.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${primarylang.split(' ')[0]}.png">${primarylang.split(' ')[1]}</a>`
  //lang_list.prepend(li_pl)
  // lang_list_2.prepend(div_pl)
  zusatzlang.forEach(langs => {
  let lang_card = newElement({element:'div',cls:['uk-card','uk-card-default','cur_pointer','lang-card'],attr:[['onclick',`langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8')`]]},lang_list)
  let lang_head = newElement({element:'div',cls:['uk-card-header','flex-column-center']},lang_card)
  let lang_img  = newElement({element:'img',cls:['sprachwahl'],attr:[['src',`images/${langs.split(' ')[0]}.png`]]},lang_head)
  let lang_body = newElement({element:'div',cls:['uk-card-body','uk-padding-small','uk-text-center']},lang_card).innerHTML = `${langs.split(' ')[1]}`
  //let div = document.createElement('div');
  //div.classList.add('col-md-3', 'col-sm-12', 'form-group')
  //div.innerHTML = `<a href="#" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${langs.split(' ')[0]}.png"> ${langs.split(' ')[1]}</a>`
  //let li = document.createElement('li');
  //li.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
  //li.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${langs.split(' ')[0]}.png">${langs.split(' ')[1]}</a>`
  //lang_list.append(li)
  // lang_list_2.append(div)
  });
}
/* The above code is used to change the placeholder of the input fields. */
  for(const key3 in document.querySelectorAll('[key-place]')){
    const element3 = document.querySelectorAll('[key-place]')[key3];
      if(element3.tagName){
       let ele = element3.getAttribute('key-place')
       element3.setAttribute('placeholder',`${params[lang][ele]}`)
       if(element3.getAttribute('placeholder')=="undefined"){
        devLangKeys[element3.getAttribute('key-place')]=element3.getAttribute('key-place')
       } else{
        devLangKeys[element3.getAttribute('key-place')]=element3.getAttribute('placeholder')
       }
      localStorage.setItem('devLang',JSON.stringify(devLangKeys))
      }
  }
  /* The above code is setting the title attribute of the element with the key-title attribute to the
  value of the key in the params object. */
  for(const key2 in document.querySelectorAll('[key-title]')){
    const element2 = document.querySelectorAll('[key-title]')[key2];
      if(element2.tagName){
       let ele = element2.getAttribute('key-title')
       element2.setAttribute('title',`${params[lang][ele]}`)
       if(element2.getAttribute('title')=="undefined"){
        devLangKeys[element2.getAttribute('key-title')]=element2.getAttribute('key-title')
       } else{
        devLangKeys[element2.getAttribute('key-title')]=element2.getAttribute('title')
       }
      localStorage.setItem('devLang',JSON.stringify(devLangKeys))
      }
  }
/* Adding a class to the element and then creating a modal for the element. */
  for(const key4 in document.querySelectorAll('[key-readme]')){
    const readmeElement = document.querySelectorAll('[key-readme]')[key4];
    if(readmeElement.tagName){
      readmeElement.classList.add('readme','mdi','mdi-help-circle-outline')
      let varRead = readmeElement.getAttribute('key-readme');
      CreateReadMeMod(varRead);
      readmeElement.setAttribute('onclick',`OpenReadMe('${varRead}')`) //Z 634
    }
  }
/* Looping through all the elements with the attribute key and replacing the innerHTML with the value
of the key in the params object. */
  for (const key in document.querySelectorAll('[key]')) {
    const element = document.querySelectorAll('[key]')[key];
    if(element.innerHTML){
    element.innerHTML = `${params[lang][element.getAttribute("key")]}`;
    if(element.innerHTML=="undefined"){
      devLangKeys[element.getAttribute('key')]=element.getAttribute('key')
    } else{
      devLangKeys[element.getAttribute('key')]=element.innerHTML
    }
    localStorage.setItem('devLang',JSON.stringify(devLangKeys))
    }
  }
  $("#sprachwahl").attr("src", `images/${lang}.png`);
}

/**
 * It sets the language to the local storage and then fetches the json file and translates the page.
 * @param {String}lang - The language you want to translate to.
 */
function langSelected(lang) {
  //let httplang = new XMLHttpRequest();
  let result = lang.substring(0, 2);
  //var url = `/production/setlanguagefile.tcls?systemsprache=${result}`;
  localStorage.setItem('lang',result)
  fetch("/production/json/lang.json", {
    mode: "no-cors",
  }) // disable CORS because path does not contain http(s)
    .then((res) => res.json())
    .then((data) => (_Translate(data)));

  //httplang.open("GET", url, true);
  //httplang.send();
}

/**
 * The function `dashboardCards` fetches data from a JSON file, disables CORS, and then calls the
 * `DashCards` function with the fetched data, followed by calling the `translatejs` function. If an
 * error occurs, the `getError` function is called.
 */
function dashboardCards() {
  try {
    fetch("/production/json/cards.json", {
      mode: "no-cors",
    }) // disable CORS because path does not contain http(s)
    .then((res) => res.json())
    .then((data) => (DashCards(data)));
  } catch (error) {
    getError(error)
  }
}

/* The above code is attempting to fetch data from a JSON file located at "/htdocs.json" using the
Fetch API in JavaScript. The fetch request is set to "no-cors" mode, which means that the response
will not be blocked by CORS (Cross-Origin Resource Sharing) restrictions. */
  try {
    fetch("/htdocs.json", {
      mode: "no-cors",
    })
    .then((res)=> res.json())
    .then((data)=>htdocs(data)) 
  } catch (error) {
    getError(error)
  }

/**
 * The function htdocs takes a JSON object as input and updates the innerHTML of all elements with the
 * class 'version' to the value of the VERSION property in the JSON object.
 * @param jsn - The parameter `jsn` is expected to be a JSON object containing information about the
 * `htdocs` version.
 */
function htdocs (jsn){
  htdocsInfo = jsn
  for (const ele of document.getElementsByClassName('version')) {
    ele.innerHTML = htdocsInfo.VERSION
  }
}
/**
 * The DashCards function creates and appends HTML elements based on the provided JSON data to display
 * dashboard cards.
 * @param jsn - The `jsn` parameter is an object that contains the data for creating the dash cards. It
 * should have a property called `dashbordcards` which is an array of objects representing each dash
 * card. Each dash card object should have the following properties:
 */
function DashCards(jsn){
  const to = document.getElementById('dash-card-holder');
  for (const key in jsn) {
    if(key === 'dashbordcards'){
      const e = jsn[key];
      for (const i of e) {
        if(i.visible === "true"){
          let div   = newElement({element:'div',id:`div_${i.name}`},to)
          let help  = newElement({element:'i',cls:['readme_card'],attr:[['key-title','ReadMe_title_help'],['key-readme',`Help_Tile_${i.name}`]]},div);
          let card  = newElement({element:'div',id:`${i.name}`,cls:['uk-card','uk-card-default','cur_pointer','dash-card'],attr:[['onclick',`LinkTo('${i.link}.tcls?check=true')`]]},div);
          let head  = newElement({element:'div',cls:['uk-card-header','flex-column-center']},card);
          let img   = newElement({element:'img',id:`img_${i.name}`,cls:['img-circle'],attr:[['width','150'],['height','135'],['src',`${i.image}`]]},head);
          let body  = newElement({element:'div',cls:['uk-card-body','uk-padding-small','uk-text-center'],attr:[['key',`${i.tkey}`]]},card).innerHTML = "<!---->";
          if(i.name === 'Seatbonemeasurement'){
            card.classList.add('no-hocker');
            localStorage.setItem('smartcube_link',false)
            img.classList.add('uk-blend-luminosity')
          }
        }
      }
    }
  }
  translatejs()
}
/**
 * It fetches the JSON file, then calls the _Translate function with the JSON file as an argument.
 */
function translatejs() {
  try {
    fetch("/production/json/lang.json?v=1", {
      mode: "no-cors",
    }) // disable CORS because path does not contain http(s)
      .then((res) => res.json())
      .then((data) => (_Translate(data)));
  } catch (error) {
    getError(error)
  }
}



/**
 * The function reinit is used to reload the current page after removing an item from the localStorage
 * and sending a GET request to a specific URL.
 */
function reinit() {
  let url = "/production/reinit.tcls";
  localStorage.removeItem('smartcube')
  httpreboot.open("GET", url, true);
  httpreboot.send();
  let inter = setInterval(()=> {
    window.location.reload(true);
      clearInterval(inter);
    }, 1000);
}
/**
 * The function starts a countdown and then reboots the Velobox
 */
function reboot() {
  var url = "/production/reboot.tcls";

  // btn1 ist das X zum schließen des Fensters
  //var btn1 = document.getElementById("btn1");
  //btn1.setAttribute("disabled", "true");
  localStorage.clear()

  var btn2 = document.getElementById("btn2");
  btn2.setAttribute("disabled", "true");

  var btn3 = document.getElementById("btn3");
  btn3.setAttribute("disabled", "true");

  countdown();

  httpreboot.open("GET", url, true);
  httpreboot.send();
} // reboot()

/**
 * It counts down from 60 seconds and reloads the page when it reaches 0
 */
function countdown() {
  var seconds = 50;
  var progress = document.getElementById('progress_restart')
  function tick() {
    seconds--;
      progress.value +=1
    if (seconds > 0) {
      setTimeout(tick, 1000);
    } else {
      location.pathname = "/"
    }
  }
   translatejs();
  tick();
}
/**
 * It takes an array of strings and creates a breadcrumb navigation bar
 * @param {Arraya<string>}params - an array of strings that will be used to create the breadcrumb.
 */
function BreadCrumb(params) {
    let path = $('.meinpfad')[0];
    path.innerHTML = "";
    let ihome = document.createElement('i');
    ihome.classList.add('mdi','mdi-sitemap')
    let spanhome = document.createElement('span');
    spanhome.setAttribute('key','mainmenu_home');
    spanhome.setAttribute('onclick',`LinkTo('dashboard.tcls')`)
    path.append(ihome);
    path.append(spanhome);
    params.forEach(element => {
      let i = document.createElement('i');
      i.classList.add('mdi','mdi-menu-right');
      path.append(i);
      let s = document.createElement('span');
      // s.classList.add('tr');
      s.setAttribute('key',`bread_${element}`)
      if(location.pathname == "/production/clients.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      if(location.pathname == "/production/newclient.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      if(location.pathname == "/production/tpfs.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      if(location.pathname == "/production/galerie.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      if(location.pathname == "/production/system.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      if(location.pathname == "/production/info.tcls"){
        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
      }
      s.setAttribute('onclick',`LinkTo('${element}.tcls')`)
      s.setAttribute('style','cursor: pointer')
      s.innerHTML = element;
      path.append(s);
      // if(element !='dashboard'){
        let li = document.createElement('li');
        let a = document.createElement('a');
        a.classList.add('font-12');
        a.setAttribute('key',`bread_${element}`);
        a.setAttribute('onclick',`LinkTo('${element}.tcls')`)
        a.setAttribute('href',`/production/${element}.tcls`)
        a.id = element.replaceAll(' ','')
        a.innerHTML = element
        //if(location.pathname == "/production/dashboard.tcls"){
        // li.classList.add('hidden')
        //}
        if(element==='client'){
          let a2 = newElement({element:'a',attr:[['onclick',`LinkTo('${element}.tcls')`],['style','display:none;']]},li)
          a.removeAttribute('key');
          a.innerHTML = `${localStorage.getItem('client_forenames')} ${localStorage.getItem('client_surename')}`
          a.setAttribute('href',`/production/client.tcls`)
          a.setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${localStorage.getItem('client_name')}','${localStorage.getItem('client_forenames')}','${localStorage.getItem('client_surename')}','${localStorage.getItem('client_mail')||""}','${localStorage.getItem('client_fc')}')`)
          //info(`${localStorage.getItem('client_id')}`,`${localStorage.getItem('client_name')}`,`${localStorage.getItem('client_mail')||""}`,`${localStorage.getItem('client_fc')}`)
          s.removeAttribute('key');
          s.innerHTML = localStorage.getItem('client_name')
        }
        menu_bread.append(li)
        li.append(a)
    });
}
/**
 * It removes the local storage items 'ReadFirstStart' and 'ReadFirstSatteldruckanalyse'
 */
function HelpReset() {
  localStorage.removeItem("ReadFirstStart");
  localStorage.removeItem("ReadFirstSatteldruckanalyse");
}

/**
 * It sends a request to the server to get the handbook file for the selected language
 * @param sprache - The language of the handbook.
 */
 function setHandbuchfile(sprache) {
  var url = "/production/korrekturhandbuch.tcls?sprache=" + sprache;
  httpSetconfig.open("GET", url, true);
  httpSetconfig.send();
}

/**
 * The function takes a parameter, which is the name of the page you want to link to, and then it
 * changes the location of the current page to the page you want to link to
 * @param params - The name of the parameter you want to pass to the function.
 */
function LinkTo(params) {
  console.log(params);
  location.href = `/production/${params}`
  localStorage.setItem('force',false)
}

function mod_about() {
  UIkit.modal("#modal-about").show();
}

/**
 * The function "PrintLog" logs a message to the console if the "log" variable is true.
 * @param {Array<String>}params - The parameter "params" is a variable that represents the data or message that needs
 * to be logged. It is passed as an argument to the function "PrintLog".
 */
function PrintLog(params) {
  if (log) {
    params.forEach(element => {
      console.log(element);
    });
  }
}

/**
* It checks if the user has already seen the first start modal and if not, it shows it
*/
function localstart() {

  if (localStorage.getItem("ReadFirstStart") === null) {
      console.log("Init FirstStart");
      localStorage.setItem("ReadFirstStart", false);
  }

  if (localStorage.getItem("viewmode") === null) {
      console.log("Init ViewMode");
      localStorage.setItem("viewmode", "basic");
  }

  if (localStorage.getItem("ReadFirstSatteldruckanalyse") === "false" && document.getElementById("firstsatteldruckanalyse")) {
      $("#firstsatteldruckanalyse").modal("show");
  }

  if (localStorage.getItem("ReadFirstStart") === "false" && location.pathname == "/production/dashboard.tcls") {
      //$("#firststart").modal("show");
      UIkit.modal("#firststart").show();
  } else {
      console.log(
          "FirstStart deactivated",
          localStorage.getItem("ReadFirstStart")
      );
  }
}

if(location.pathname == "/production/dashboard.tcls"){
  dashboardCards()
  BreadCrumb(['dashboard']);
}
if(location.pathname == "/production/clients.tcls"){
  BreadCrumb(['dashboard','clients']);
}
if(location.pathname == "/production/newclient.tcls"){
  BreadCrumb(['dashboard','clients','newclient']);
}
if(location.pathname == "/production/client.tcls"){
  BreadCrumb(['dashboard','clients','client'])
}
if(location.pathname == "/production/saddle_pressure_analysis.tcls"){
  BreadCrumb(['dashboard','clients','client','saddle_pressure_analysis']);
}
if(location.pathname == "/production/anamnese.tcls"){
  BreadCrumb(['dashboard','clients','client','anamnese']);
}
if(location.pathname == "/production/protokoll.tcls"){
  BreadCrumb(['dashboard','clients','client','protokoll','galerie'])
}
if(location.pathname == "/production/galerie.tcls"){
  BreadCrumb(['dashboard','clients','client','protokoll','galerie'])
}
if(location.pathname == "/production/handbuch.tcls"){
  BreadCrumb(['dashboard','handbuch'])
}
if(location.pathname == "/production/system.tcls"){
  BreadCrumb(['dashboard','system'])
}
if(location.pathname == "/production/sitzknochenvermessung.tcls"){
  BreadCrumb(['dashboard','sitzknochenvermessung'])
}
if(location.pathname == "/production/wlanconfig.tcls"){
  BreadCrumb(['dashboard','wlanconfig'])
}
if(location.pathname == "/production/changelog.tcls"){
  BreadCrumb(['dashboard','changelog'])
}
if(location.pathname == "/production/tpfs.tcls"){
  BreadCrumb(['dashboard','tpfs'])
}
if(location.pathname == "/production/products.tcls"){
  BreadCrumb(['dashboard','tpfs','products'])
}
if(location.pathname == "/production/info.tcls"){
  BreadCrumb(['dashboard','info'])
}

var checkbox = document.getElementById('basic');
var checkbox_view = document.getElementById('switch-1')
if(document.getElementById('switch-demo'))
var checkbox_demo = document.getElementById('switch-demo')
var checkbox_mask1 = document.getElementById('mask1')
var checkbox_mask2 = document.getElementById('mask2')
var checkbox_set_comp = document.getElementById('set_comp')
var checkbox_maskedit = document.getElementById('maskedit');

/**
 * The function `chk_wifi()` checks the status of the Ethernet and WiFi connections and updates the
 * corresponding elements on the webpage accordingly.
 */
function chk_wifi() {
const btn_eth = document.getElementById('eth');
const span_eth = document.getElementById('eth_con');

try {
  if(btn_eth.dataset.inet == ""){
    btn_eth.classList.remove('mdi-lan-connect')
    btn_eth.classList.add('mdi-lan-disconnect')
    btn_eth.setAttribute('disabled','')
    span_eth.setAttribute('style','color: var(--red);')
  } else {
    span_eth.setAttribute('style','color: var(--primary);')
  }
} catch (error) {
  getError(error)
}


//WIFI-CONN
//mdi-wifi-off
const btn_wifi = document.getElementById('wifi')
const span_wifi = document.getElementById('wifi_con')
const li_id = document.getElementById('wifi_id')
const li_id_hr = document.getElementById('wifi_id_hr')

try {
  if(btn_wifi.dataset.inet != ""){
    span_wifi.setAttribute('style','color: var(--primary);')
  } else {
    btn_wifi.classList.remove('mdi-wifi')
    btn_wifi.classList.add('mdi-wifi-off')
    span_wifi.setAttribute('style','color: var(--red);')
    span_wifi.setAttribute('key','con_disconekt')
    li_id.classList.add('hidden')
    li_id_hr.classList.add('hidden')
    translatejs()
  }
} catch (error) {
  getError(error)
}
}

/* The above code is adding an event listener to a checkbox element with the id "checkbox_view". When
the checkbox is checked, it logs "basic is checked.." to the console and calls the function
ToggleViewMode with the argument 'advanced'. When the checkbox is unchecked, it logs "basic is not
checked.." to the console and calls the function ToggleViewMode with the argument 'basic'. */
checkbox_view.addEventListener('change', function() {
if (this.checked) {
  console.log("basic is checked..");
  // document.getElementById("basic").nextSibling.classList.add('custom_switch')
  ToggleViewMode('advanced');
} else {
  console.log("basic is not checked..");
  // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
  ToggleViewMode('basic');
}
});

if(document.getElementById('switch-demo')){
  if(script_setting.demo == 'true'){
    checkbox_demo.setAttribute('checked','')
  }
  checkbox_demo.addEventListener('change',()=>{
    setDemomode()
  })
}

try {
  checkbox_mask1.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("mask1").nextSibling.classList.add('custom_switch')
      showMask(this.dataset.num)
    } else {
      document.getElementById("mask1").nextSibling.classList.remove('custom_switch')
      hideMask(this.dataset.num)
    }
    });
} catch (error) {
  //getError(error)
}

try {
  checkbox_mask2.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("mask2").nextSibling.classList.add('custom_switch')
      showMask(this.dataset.num)
    } else {
      document.getElementById("mask2").nextSibling.classList.remove('custom_switch')
      hideMask(this.dataset.num)
    }
});
} catch (error) {
  //getError(error)
}

try {
  checkbox_maskedit.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("maskedit").nextSibling.classList.add('custom_switch')
      hide_mask()
    } else {
      document.getElementById("maskedit").nextSibling.classList.remove('custom_switch')
      hide_mask()
    }
});
} catch (error) {
  //getError(error)
}

try {
  checkbox_set_comp.addEventListener('change', function() {
    console.log(this.dataset.num);
    if (this.checked) {
      document.getElementById("set_comp").nextSibling.classList.add('custom_switch')
      set_comp("on")
    } else {
      document.getElementById("set_comp").nextSibling.classList.remove('custom_switch')
      set_comp("off")
    }
    });
} catch (error) {
  //getError(error)
}

var men = document.getElementById('menu_toggle');

men.addEventListener('click',()=>{
let m_men = document.getElementsByClassName('men');

  if(document.getElementsByTagName('body')[0].classList.contains('nav-md')){
    for (const iterator of m_men) {
      iterator.classList.add('hide')
    }
  } else {
    for (const iterator of m_men) {
      iterator.classList.remove('hide')
    }
  }
})

/**
 * It takes a string, and returns a translated string
 * @param {String}params - The string you want to translate.
 * @returns The value of the key in the object.
 */
function gettrans(params) {
  lang = localStorage.getItem('lang')
  console.log(params,lang);
  translatejs()
  console.log(aLangKeys);
  try {
  return aLangKeys[lang][params]
  } catch (error) {
    getError(error)
  }
}

/**
 * It sets the position of the element with the id of "foo" to fixed, and sets the width and height of
 * the element to the width and height of the window
 */
function abso() {
ch = $(window).height();
cw = $(window).width()/1.25;
  $('#foo').css({
      position: 'fixed',
      background: 'white !important',
      zIndex: 1000,
      width: $(window).width(),
      height: $(window).height(),
      top: 0,
      right: '10%',
      bottom: 0,
      left: '10%'
  });
}


try {
let side_smartcube = document.getElementById('sitzknochen-menu');
  side_smartcube.setAttribute('href','/production/seat_bone.tcls?check=true')
} catch (error) {
  getError(error)
}


/* The above code is creating a clock that updates every second. It uses the setInterval function to
execute a function every 1000 milliseconds (1 second). Inside the function, it gets the current time
using the Date object. It then formats the time into hours, minutes, and seconds, adding leading
zeros if necessary. Finally, it updates the innerHTML of an element with the id 'clock' with the
formatted time. */
let clock_dash = setInterval(function () {
  if(aLangKeys[lang]){
  let c = document.getElementById('clock');
  let time = new Date();
  let h = time.getHours() < 10 ? '0' + time.getHours() : time.getHours();
  let m = time.getMinutes() < 10 ? '0' + time.getMinutes() : time.getMinutes();
  let s = time.getSeconds() < 10 ? '0' + time.getSeconds() : time.getSeconds();
  let time_str = `${aLangKeys[lang][week[time.getDay()||1]]} ${time.getDate()} ${aLangKeys[lang][month[time.getMonth()||1]]} ${h}:${m}:${s}`;
  c.innerHTML = time_str;
  }
 }, 1000);
// $(window).resize(function() {
//   abso();
// });

/**
 * It creates a new element with the given parameters and appends it to the given element
 *
 * @function
 * @name newElement
 * @kind function
 * @param {Object<JSON>} jsn - JSON object
 * @param {String} jsn.element    - HTML element name
 * @param {String} jsn.id    - ID of the element
 * @param {Array<String>} jsn.cls - classes of the element
 * @param {Array<Array<String>>} jsn.attr - Attriburtes of the HTML element
 * @param {HTMLElement} DOM_Element - the complete element
 * @returns {HTMLElement}
 */
function newElement(jsn, DOM_Element) {
  let e = document.createElement(jsn.element)
  if(jsn.cls){
      jsn.cls.forEach(element => {
          e.classList.add(element)
      });
  }
  if(jsn.id){
      e.id = jsn.id
  }
  if(jsn.attr){
      jsn.attr.forEach(element=>{
          e.setAttribute(element[0],element[1])
      });
  }
  if(log){
    console.log('newElement',e);
  }
  DOM_Element.append(e)
  return e;
}

// MODAL README
/**
 * It creates a modal window with a button to close it, and then fetches the HTML file from the server
 * and inserts it into the modal window
 * @param {String}params - the name of the file to be loaded.
 */
function CreateReadMeMod(params) {
  let append;
  if(document.getElementById('ModalHolder')){
    append = document.getElementById('ModalHolder');
  } else {
    append = newElement({element:'div',id:'ModalHolder'},document.getElementsByTagName('body')[0]);
  }

  let ModalDiv  =  newElement({element:'div',id:`mod_${params}`,attr:[['uk-modal','']]},append);
  let ModalBody =  newElement({element:'div',cls:['uk-modal-dialog','uk-modal-body']},ModalDiv);
  let ModalBtnX =  newElement({element:'button',cls:['uk-modal-close-default'],attr:[['type','button'],['uk-close','']]},ModalBody);
  let ModalReadmeText1 = newElement({element:'p'},ModalBody);

  try {
    fetch(`/production/manuals/${lang}/${params}.html?v=1`, {
      mode: "no-cors",
    }) // disable CORS because path does not contain http(s)
      .then((res) => res.text())
      .then((data) => (ModalReadmeText1.innerHTML=data));
  } catch (error) {
    ModalReadmeText1.innerHTML = error;
    getError(error)
  }
}


/**
 * The function displays an error message in a dialog box.
 * @param err - The "err" parameter is a variable that is expected to contain an error message or
 * object. This function takes that error and displays it in a dialog box with the title "error" and a
 * single "OK" button for the user to dismiss the dialog.
 */
function getError (err){
  console.log('getError',err);
  OpenModDialog({type:'error',title:["error"],msg:JSON.stringify(err),master_btn:['button_ok']})
}

/**
 * > This function opens a modal window with the id of `mod_`
 * @param {String}params - The name of the modal you want to open.
 */
function OpenReadMe(params) {
  UIkit.modal(`#mod_${params}`).show();
}

/**
 * If the error message is not displayed, display it. Otherwise, hide it
 */
function showErrormessage() {
  let x = document.getElementsByClassName("error_p");
  for (const ele of x) {
    if (ele.style.display === "none") {
      ele.style.display = "block";
  } else {
      ele.style.display = "none";
  }
  }
}


/**
 * The openWindow function redirects the user to the dashboard page.
 */
function openWindow() {
  location.pathname = 'production/dashboard.tcls'
}

/**
 * The function opens a new window with a specific URL and dimensions, and then closes the current
 * window.
 */
function openNewWindow() {
  window.open(`${location.origin}/production/dashboard.tcls`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
  closeWindow()
}

/**
 * The closeWindow function opens a new window and then closes the current window.
 */
function closeWindow() {
  window.open('','_parent','');
  window.close();
}

// sample warn
//let dialogSample = {type:'warn',title:"Sitzung #215 löschen?",msg:["cli_session_text"],master_btn:["button_delete","SelectSessionDel()"],slave_btn:["button_cancel"]}
/**
 * It creates a modal dialog with a header, body and footer
 * @param {JSON.type}jsn - head:"overwrites the defautl head",title:what happend, msg:more info hidden,master_btn:[translationkey,onclick(nothing=close),slave_btn:[translationkey,onclick(nothing=close)]
 * @type {String} -warn || error || neutral || success
 * @head {Sring} - overwrites the head
 * @title {String || Array} -Array:set an translate key -String: a normal string
 * @msg {string || Array} - Array: set the translate key for more informations -String: a normal string (server messages)
 * @master_btn {Array<String>} - ["transKey",functon()-optional] if no function default is close modal --Optional
 * @slave_btn {Array<String>} - ["transKey",functon()-optional] if no function default is close modal --Optional
 */
function OpenModDialog(jsn){
let holder;
if(document.getElementById('ModalHolder')){
  holder = document.getElementById('ModalHolder');
} else {
  holder = newElement({element:'div',id:'ModalHolder'},document.getElementsByTagName('body')[0]);
}

let modal = newElement({element:'div',attr:[['uk-modal','']]},holder)
let dialog= newElement({element:'div',cls:['uk-modal-dialog']},modal)
let head  = newElement({element:'div',cls:['uk-modal-header',`mod_${jsn.type}`]},dialog)
  let title = newElement({element:'h2',cls:['uk-modal-title'],attr:[['style','color:var(--secondary-text)'],[`key`,`mod_${jsn.type}`]]},head).innerHTML = '<!--title-->'
if(jsn.head){
  let title = newElement({element:'h2',cls:['uk-modal-title'],attr:[['style','color:var(--secondary-text)']]},head).innerHTML = jsn.head
}
let X = newElement({element:'button',cls:['uk-modal-close-default'],attr:[['uk-close','']]},head)
let body = newElement({element:'div',cls:['uk-modal-body']},dialog)
let h4 = newElement({element:'h4',attr:[['style','color:var(--primary-text)'],['onclick','showErrormessage()']]},body)
let h4d= newElement({element:'div',cls:['info_msg','uk-margin-bottom']},h4)
if(jsn.type === 'warn'){
  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-alert'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
}
if(jsn.type === 'error'){
  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-minus-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
}
if(jsn.type === 'success'){
  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-help-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
}
if(jsn.type === 'neutral'){
  let ico = newElement({element:'span',cls:['uk-margin-right','ico-16','mdi','mdi-alert-circle'],attr:[['style',`color:var(--${jsn.type})`]]},h4d)
}
if(Array.isArray(jsn.title)){
  let warn = newElement({element:'span',attr:[['key',jsn.title[0]]]},h4d).innerHTML = '<!--title-->'
} else{
  let warn = newElement({element:'span'},h4d).innerHTML = jsn.title

}
let p = newElement({element:'p',cls:['error_p'],attr:[['style','display:none']]},h4)
if(Array.isArray(jsn.msg)){
let span = newElement({element:'span',attr:[['key',jsn.msg]]},p).innerHTML= '<!--msg-->'
} else {
let span = newElement({element:'span'},p).innerHTML= jsn.msg
}
let foot = newElement({element:'div',cls:['uk-modal-footer','uk-text-right']},dialog)
if(jsn.slave_btn){
  let slave = newElement({element:'button',cls:['uk-button', 'uk-button-default', 'uk-modal-close'],attr:[['key',jsn.slave_btn[0]]]},foot)
  if(jsn.slave_btn[1])
  slave.setAttribute('onclick',jsn.slave_btn[1])
  slave.innerHTML = '<!--title-->'
}
if (jsn.master_btn) {
  let master = newElement({element:'button',cls:['uk-margin-left','uk-button', `uk-button-${jsn.type}`, 'uk-modal-close'],attr:[['key',jsn.master_btn[0]]]},foot)
  if(jsn.master_btn[1])
  master.setAttribute('onclick',jsn.master_btn[1])
  master.innerHTML = '<!--title-->'
}
translatejs()
UIkit.modal(modal).show();
}

var elem = document.documentElement;
var fullScreen = false

/**
 * The function toggles between opening and closing fullscreen mode.
 */
function Vollbild() {
    if (fullScreen) {
        closeFullscreen()
        }
    if (!fullScreen) {
        openFullscreen()
        }
    }

/**
 * The function opens the browser in fullscreen mode if supported by the browser.
 */
function openFullscreen() {
    if (elem.requestFullscreen) {
        elem.requestFullscreen();
        }
    else if (elem.mozRequestFullScreen) { /* Firefox */
        elem.mozRequestFullScreen();
        }
    else if (elem.webkitRequestFullscreen) { /* Chrome, Safari & Opera */
        elem.webkitRequestFullscreen();
        }
    else if (elem.msRequestFullscreen) { /* IE/Edge */
        elem.msRequestFullscreen();
        }
        fullScreen = true
    }

/**
 * The closeFullscreen function is used to exit fullscreen mode in a web browser.
 */
function closeFullscreen() {
    if (document.exitFullscreen) {
        document.exitFullscreen();
        }
    else if (document.mozCancelFullScreen) {
        document.mozCancelFullScreen();
        }
    else if (document.webkitExitFullscreen) {
        document.webkitExitFullscreen();
        }
    else if (document.msExitFullscreen) {
        document.msExitFullscreen();
        }
        fullScreen=false
    }

/**
 * The function `setUserCompany` sets the value of `script_setting.UserCompany` to the provided
 * parameter.
 * @param params - The `params` parameter is a variable that represents the value you want to set for
 * the `UserCompany` property in the `script_setting` object.
 */
function setUserCompany(params){
  script_setting.UserCompany = params
}

/**
 * The function sets the value of the UserName property in the script_setting object.
 * @param params - The `params` parameter is a variable that represents the value you want to set as
 * the username.
 */
function setUserName(params){
  script_setting.UserName = params
}

/**
 * The function `setUserCity` sets the user's city in a script setting.
 * @param params - The `params` parameter is a variable that represents the value you want to set for
 * the `UserCity` property in the `script_setting` object.
 */
function setUserCity(params){
  script_setting.UserCity = params
}

/**
 * The function `setUserStreet` sets the value of `script_setting.UserStreet` to the provided
 * parameter.
 * @param params - The `params` parameter is a variable that represents the value of the user's street
 * address.
 */
function setUserStreet(params){
  script_setting.UserStreet = params
}

/**
 * The function `setUserMail` sets the value of `script_setting.UserMail` to the provided parameter.
 * @param params - The `params` parameter is the email address that you want to set for the user.
 */
function setUserMail(params){
  script_setting.UserMail = params
}

/**
 * The function `setUserWeb` sets the value of `script_setting.UserWeb` to the provided parameter.
 * @param params - The `params` parameter is a variable that represents the value you want to set for
 * the `UserWeb` property in the `script_setting` object.
 */
function setUserWeb(params){
  script_setting.UserWeb = params
}

/**
 * The function `setUserPhone` sets the value of `script_setting.UserPhone` to the provided parameter.
 * @param params - The `params` parameter is the value that will be assigned to the `UserPhone`
 * property of the `script_setting` object.
 */
function setUserPhone(params){
  script_setting.UserPhone = params
}

/**
 * The function `setUserUnit` sets the `UserUnit` property of the `script_setting` object to the
 * provided parameter.
 * @param params - The `params` parameter is the value that will be assigned to the `UserUnit` property
 * of the `script_setting` object.
 */
function setUserUnit(params){
  script_setting.UserUnit = params
}

/**
 * The function setUserEinleitung sets the UserEinleitung property in the script_setting object to the
 * provided parameter.
 * @param params - The `params` parameter is a variable that can hold any value. It is used as an
 * argument when calling the `setUserEinleitung` function. The purpose of this function is to set the
 * value of the `UserEinleitung` property in the `script_setting` object.
 */
function setUserEinleitung(params){
  script_setting.UserEinleitung = params
}

/**
 * The function `saveConfig` sends the client settings as a JSON string over a WebSocket connection.
 */
function saveConfig(){
  script_websocket.send(`set clientsettings ${JSON.stringify(script_setting)}`)
}

$(document).ready(function () {
  translatejs();
  localstart();
  chk_wifi();
  ToggleViewMode(localStorage.getItem("viewmode"));
  if(localStorage.getItem('viewmode')==='basic'){
    checkbox_view.removeAttribute('checked');
    // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
    ToggleViewMode('basic');
  } else{
    try {
    checkbox_view.setAttribute('checked','')
    // document.getElementById("basic").nextSibling.classList.add('custom_switch')
    ToggleViewMode('advanced');
  } catch (error) {
    getError(error)
    }
  }
  if(location.pathname == "/production/saddle_pressure_analysis.tcls"){
    checkbox_mask1.removeAttribute('checked')
    checkbox_mask2.removeAttribute('checked')
    checkbox_maskedit.removeAttribute('checked')
    if(script_setting.demo == "true")
    checkbox_demo.setAttribute('checked','true')
  }
});

//const input = document.querySelector("input");

const input = document.getElementsByTagName('input')

for (const i of input) {
  i.addEventListener("input",updateValue)
}

/**
 * The function `updateValue` is used to update the value of an input element and display a warning
 * notification if the value contains either a double quote or a single quote.
 * @param e - The parameter `e` is an event object that is passed to the function when it is called as
 * an event handler. It represents the event that triggered the function, such as a keypress or a
 * change in an input field.
 */
function updateValue(e) {
  const color = "var(--light-4)"
  let txt = this.value
  let ele = this

  if(typeof this.value === "undefined"){
    txt = e.value
    ele = e
  }

  if(txt.includes('"')){
    ele.value = ele.value.replaceAll('"','')
    UIkit.notification({message: `" ${aLangKeys[lang].not_allowed}`, status: 'warn'})
  }

  if(txt.includes("'")){
    ele.value = ele.value.replaceAll("'",'')
    UIkit.notification({message: `' ${aLangKeys[lang].not_allowed}`, status: 'warn'})
  }
}

try {
  fetch("https://downloads.velometrik.de/version.json")
  .then((res)=> res.json())
  .then((data)=> info_update(data))
} catch (error) {
  console.error(error);
}

function info_update(jsn){

  let comp = setInterval(()=> {

    let aV = htdocsInfo.VERSION.replaceAll('.','')
  if(document.getElementById('dl_info')){
    var t = document.getElementById('dl_info')
    var i = 0
    jsn.versionen.forEach(e => {
      let nV = e.version.replaceAll('.','')
      if (aV < nV) {
        i++
        t.classList.remove('hidden')
        if(localStorage.getItem('ReadFirstStart') == "true" && location.pathname == '/production/dashboard.tcls' && i==1){
          OpenInfoBox(`${e.version}`)
        } else if (localStorage.getItem('ReadFirstStart') == "false" && location.pathname == '/production/dashboard.tcls'&& i==1){
          let btn = document.getElementById("firststart_button")
          btn.setAttribute('onclick',`OpenInfoBox("${e.version}")`)
        }
      }
      return;
    });
}

    clearInterval(comp);
  }, 500);

  
}

function OpenInfoBox(params){
  OpenModDialog({type:'neutral',head:aLangKeys[lang]["new_update_head"],title:["new_update_title"],msg:`Version: ${params}`,master_btn:["button_ok","LinkTo('system.tcls')"],slave_btn:["button_cancel"]})
}

try {
  fetch("https://downloads.velometrik.de/infos.json")
  .then((res) => res.json())
  .then((data) => (DashCards(data)));
} catch (error) {
  console.error(error);
}

function TESTJSN(){
  let jsn = aLangKeys
  let keys = []
  let langs = []
  
  jsn.zusatzlang.forEach(element => {
      langs.push(element.split(' ')[0])
  });

  for (const key in jsn.de) {
          keys.push(key)
  }

  langs.forEach(element => {
      console.log(element);
      if(jsn[element]){
          console.log(element,"exist");
          let a = {}
          a[element]={}
          keys.forEach(element2 => {
              if(!jsn[element][element2]){
                  a[element][element2] = element2
              }
          });
          console.error(a);
      } else {
          console.error(element,"not exist");
      }
  });

  console.log(keys,langs);
}

function setDemomode() {
  if(!script_setting.demo){
    script_setting.demo = "false"
  }
  script_setting.demo = script_setting.demo == 'false' ? "true" : "false";

  //document.getElementById('btn_demo_mode').style.color = document.getElementById('btn_demo_mode') && script_setting.demo == 'true' ? 'var(--warn)' : 'unset';
  
  document.getElementById('demo_mode').innerHTML = document.getElementById('demo_mode') && script_setting.demo == 'true' ? 'DEMO MODE' : '';

  saveConfig();

  if(location.pathname === "/production/saddle_pressure_analysis.tcls"){
    SessReload();
  }
}